@@ -143,6 +143,8 @@ EXTERN BOOL_VAR (tessedit_global_adaption, FALSE,
 EXTERN BOOL_VAR (tessedit_matcher_log, FALSE, "Log matcher activity");
 EXTERN INT_VAR (tessedit_test_adaption_mode, 3,
 "Adaptation decision algorithm for tess");
+BOOL_VAR (save_best_choices, FALSE, "Save the results of the recognition step"
+" (blob_choices) within the corresponding WERD_CHOICE");
 
 EXTERN BOOL_VAR (test_pt, FALSE, "Test for point");
 EXTERN double_VAR (test_pt_x, 99999.99, "xcoord");
@@ -156,7 +158,7 @@ FILE *choice_file = NULL;        //Choice file ptr
 
 CLISTIZEH (PBLOB) CLISTIZE (PBLOB)
 /* DEBUGGING */
-INT16 blob_count(WERD *w) {
+inT16 blob_count(WERD *w) {
   return w->blob_list ()->length ();
 }
 
@@ -169,7 +171,7 @@ INT16 blob_count(WERD *w) {
 
 void recog_pseudo_word(                         //recognize blobs
                        BLOCK_LIST *block_list,  //blocks to check
-                       BOX &selection_box) {
+                       TBOX &selection_box) {
   WERD *word;
   ROW *pseudo_row;               //row of word
   BLOCK *pseudo_block;           //block of word
@@ -195,8 +197,8 @@ BOOL8 recog_interactive(            //recognize blobs
                         WERD *word  //word to recognize
                        ) {
   WERD_RES word_res(word);
-  INT16 char_qual;
-  INT16 good_char_qual;
+  inT16 char_qual;
+  inT16 good_char_qual;
 
   classify_word_pass2(&word_res, row);
   #ifndef SECURE_NAMES
@@ -222,32 +224,32 @@ BOOL8 recog_interactive(            //recognize blobs
 void recog_all_words(                              //process words
                      PAGE_RES *page_res,           //page structure
                      volatile ETEXT_DESC *monitor,  //progress monitor
-                     BOX	*target_word_box,//specifies just to extract a retangle
-                     INT16 dopasses //0 - all, 1 just pass 1, 2 passes 2 and higher
+                     TBOX	*target_word_box,//specifies just to extract a retangle
+                     inT16 dopasses //0 - all, 1 just pass 1, 2 passes 2 and higher
 					 ) {
                                  //reset page iterator
   static PAGE_RES_IT page_res_it;
-  INT16 chars_in_word;
-  INT16 rejects_in_word;
+  inT16 chars_in_word;
+  inT16 rejects_in_word;
   static CHAR_SAMPLES_LIST em_clusters;
   static CHAR_SAMPLE_LIST ems_waiting;
   static CHAR_SAMPLES_LIST char_clusters;
   static CHAR_SAMPLE_LIST chars_waiting;
-  INT16 blob_quality = 0;
-  INT16 outline_errs = 0;
-  static INT16 doc_blob_quality = 0;
-  static INT16 doc_outline_errs = 0;
-  static INT16 doc_char_quality = 0;
-  INT16 all_char_quality;
-  INT16 accepted_all_char_quality;
-  static INT16 good_char_count = 0;
-  static INT16 doc_good_char_quality = 0;
+  inT16 blob_quality = 0;
+  inT16 outline_errs = 0;
+  static inT16 doc_blob_quality = 0;
+  static inT16 doc_outline_errs = 0;
+  static inT16 doc_char_quality = 0;
+  inT16 all_char_quality;
+  inT16 accepted_all_char_quality;
+  static inT16 good_char_count = 0;
+  static inT16 doc_good_char_quality = 0;
   int i;
 
 
-  INT32 tess_adapt_mode = 0;
-  static INT32 word_count;              //count of words in doc
-  INT32 word_index;              //current word
+  inT32 tess_adapt_mode = 0;
+  static inT32 word_count;              //count of words in doc
+  inT32 word_index;              //current word
   static int dict_words;
 
   if (tessedit_minimal_rej_pass1) {
@@ -385,7 +387,7 @@ if (dopasses==1) return;
 	if (target_word_box)
 	{
 
-		BOX current_word_box=page_res_it.word ()->word->bounding_box();
+		TBOX current_word_box=page_res_it.word ()->word->bounding_box();
 		FCOORD center_pt((current_word_box.right()+current_word_box.left())/2,(current_word_box.bottom()+current_word_box.top())/2);
 		if (!target_word_box->contains(center_pt))
 		{
@@ -440,7 +442,7 @@ if (dopasses==1) return;
 	if (target_word_box)
 	{
 
-		BOX current_word_box=page_res_it.word ()->word->bounding_box();
+		TBOX current_word_box=page_res_it.word ()->word->bounding_box();
 		FCOORD center_pt((current_word_box.right()+current_word_box.left())/2,(current_word_box.bottom()+current_word_box.top())/2);
 		if (!target_word_box->contains(center_pt))
 		{
@@ -481,7 +483,7 @@ if (dopasses==1) return;
       page_res_it.row ()->row,
       &all_char_quality, &accepted_all_char_quality);
     doc_char_quality += all_char_quality;
-    UINT8 permuter_type = page_res_it.word ()->best_choice->permuter ();
+    uinT8 permuter_type = page_res_it.word ()->best_choice->permuter ();
     if ((permuter_type == SYSTEM_DAWG_PERM) ||
       (permuter_type == FREQ_DAWG_PERM) ||
     (permuter_type == USER_DAWG_PERM)) {
@@ -508,7 +510,7 @@ if (dopasses==1) return;
 	if (target_word_box)
 	{
 
-		BOX current_word_box=page_res_it.word ()->word->bounding_box();
+		TBOX current_word_box=page_res_it.word ()->word->bounding_box();
 		FCOORD center_pt((current_word_box.right()+current_word_box.left())/2,(current_word_box.bottom()+current_word_box.top())/2);
 		if (!target_word_box->contains(center_pt))
 		{
@@ -582,14 +584,20 @@ void classify_word_pass1(                 //recog one word
                          CHAR_SAMPLE_LIST *chars_waiting) {
   WERD *bln_word;                //baseline norm copy
                                  //detailed results
-  BLOB_CHOICE_LIST_CLIST blob_choices;
+  BLOB_CHOICE_LIST_CLIST local_blob_choices;
+  BLOB_CHOICE_LIST_CLIST *blob_choices;
   BOOL8 adapt_ok;
   const char *rejmap;
-  INT16 index;
+  inT16 index;
   STRING mapstr = "";
   char *match_string;
   char word_string[1024];
 
+  if (save_best_choices)
+    blob_choices = new BLOB_CHOICE_LIST_CLIST();
+  else
+    blob_choices = &local_blob_choices;
+
   if (matcher_fp != NULL) {
     fgets (word_string, 1023, correct_fp);
     if ((match_string = strchr (word_string, '\r')) != NULL)
@@ -610,7 +618,7 @@ void classify_word_pass1(                 //recog one word
 
   word->best_choice = tess_segment_pass1 (bln_word, &word->denorm,
     tess_default_matcher,
-    word->raw_choice, &blob_choices,
+    word->raw_choice, blob_choices,
     word->outword);
   /*
      Test for TESS screw up on word. Recog_word has already ensured that the
@@ -629,17 +637,17 @@ void classify_word_pass1(                 //recog one word
     word->tess_failed = FALSE;
     if ((word->best_choice->lengths ().length () !=
       word->outword->blob_list ()->length ()) ||
-    (word->best_choice->lengths ().length () != blob_choices.length ())) {
+    (word->best_choice->lengths ().length () != blob_choices->length ())) {
       tprintf
         ("ASSERT FAIL String:\"%s\"; Strlen=%d; #Blobs=%d; #Choices=%d\n",
         word->best_choice->string ().string (),
         word->best_choice->lengths ().length (),
-        word->outword->blob_list ()->length (), blob_choices.length ());
+        word->outword->blob_list ()->length (), blob_choices->length ());
     }
     ASSERT_HOST (word->best_choice->lengths ().length () ==
       word->outword->blob_list ()->length ());
     ASSERT_HOST (word->best_choice->lengths ().length () ==
-      blob_choices.length ());
+      blob_choices->length ());
 
     /*
        The adaption step used to be here. It has been moved to after
@@ -657,10 +665,10 @@ void classify_word_pass1(                 //recog one word
     else {
       fix_quotes (word->best_choice,
       //turn to double
-        word->outword, &blob_choices);
+        word->outword, blob_choices);
       if (tessedit_fix_hyphens)
                                  //turn 2 to 1
-        fix_hyphens (word->best_choice, word->outword, &blob_choices);
+        fix_hyphens (word->best_choice, word->outword, blob_choices);
       record_certainty (word->best_choice->certainty (), 1);
       //accounting
 
@@ -671,7 +679,7 @@ void classify_word_pass1(                 //recog one word
         word->best_choice,
         word->raw_choice);
                                  // Also sets word->done flag
-      make_reject_map (word, &blob_choices, row, 1);
+      make_reject_map (word, blob_choices, row, 1);
 
       adapt_ok = word_adaptable (word, tessedit_tess_adaption_mode);
 
@@ -702,7 +710,7 @@ void classify_word_pass1(                 //recog one word
 
       if (tessedit_enable_doc_dict)
         tess_add_doc_word (word->best_choice);
-      set_word_fonts(word, &blob_choices);
+      set_word_fonts(word, blob_choices);
     }
   }
 #if 0
@@ -712,7 +720,12 @@ void classify_word_pass1(                 //recog one word
   }
 #endif
   delete bln_word;
-  blob_choices.deep_clear ();
+
+  // Save best choices in the WERD_CHOICE if needed
+  if (blob_choices != &local_blob_choices)
+    word->best_choice->set_blob_choices(blob_choices);
+  else
+    blob_choices->deep_clear();
 }
 
 
@@ -728,16 +741,16 @@ void classify_word_pass2(  //word to do
   BOOL8 done_this_pass = FALSE;
   WERD_RES new_x_ht_word (word->word);
   float new_x_ht = 0.0;
-  INT16 old_xht_reject_count;
-  INT16 new_xht_reject_count;
-  INT16 old_xht_accept_count;
-  INT16 new_xht_accept_count;
+  inT16 old_xht_reject_count;
+  inT16 new_xht_reject_count;
+  inT16 old_xht_accept_count;
+  inT16 new_xht_accept_count;
   BOOL8 accept_new_x_ht = FALSE;
-  INT16 old_chs_in_wd;
-  INT16 new_chs_in_wd;
-  INT16 old_word_quality;
-  INT16 new_word_quality;
-  INT16 dummy;
+  inT16 old_chs_in_wd;
+  inT16 new_chs_in_wd;
+  inT16 old_word_quality;
+  inT16 new_word_quality;
+  inT16 dummy;
 
   set_global_subloc_code(SUBLOC_NORM);
   check_debug_pt (word, 30);
@@ -885,11 +898,15 @@ void classify_word_pass2(  //word to do
   }
 #ifndef GRAPHICS_DISABLED
   if (tessedit_draw_outwords) {
-    if (fx_win == NO_WINDOW)
+    if (fx_win == NULL)
       create_fx_win();
     clear_fx_win();
     word->outword->plot (fx_win);
-    make_picture_current(fx_win);
+    TBOX wbox = word->outword->bounding_box();
+    fx_win->ZoomToRectangle(wbox.left(), wbox.top(),
+                            wbox.right(), wbox.bottom());
+    //make_picture_current(fx_win);
+    ScrollView::Update();
   }
 #endif
 
@@ -916,7 +933,13 @@ void match_word_pass2(                 //recog one word
                       float x_height) {
   WERD *bln_word;                //baseline norm copy
                                  //detailed results
-  BLOB_CHOICE_LIST_CLIST blob_choices;
+  BLOB_CHOICE_LIST_CLIST local_blob_choices;
+  BLOB_CHOICE_LIST_CLIST *blob_choices;
+
+  if (save_best_choices)
+    blob_choices = new BLOB_CHOICE_LIST_CLIST();
+  else
+    blob_choices = &local_blob_choices;
 
   set_global_subsubloc_code(SUBSUBLOC_OTHER);
   if (matcher_fp != NULL) {
@@ -933,25 +956,25 @@ void match_word_pass2(                 //recog one word
       tess_default_matcher,
       tess_training_tester,
       word->raw_choice,
-      &blob_choices, word->outword);
+      blob_choices, word->outword);
   else if (tessedit_dump_choices)
     word->best_choice = test_segment_pass2 (bln_word,
         &word->denorm,
         tess_default_matcher,
         choice_dump_tester,
         word->raw_choice,
-        &blob_choices, word->outword);
+        blob_choices, word->outword);
   //      else if (tessedit_training_wiseowl)
   //              best_choice=correct_segment_pass2( word, &denorm,
   //                                                                                                        tess_default_matcher,wo_learn,
-  //                                                                                                        raw_choice,&blob_choices,outword);
+  //                                                                                                        raw_choice,blob_choices,outword);
   //      else if (tessedit_matcher_is_wiseowl)
   //              best_choice=tess_segment_pass2( word, &denorm, wo_classify,
-  //                                                                                                raw_choice, &blob_choices, outword);
+  //                                                                                                raw_choice, blob_choices, outword);
   else {
     word->best_choice = tess_segment_pass2 (bln_word, &word->denorm,
       tess_default_matcher,
-      word->raw_choice, &blob_choices,
+      word->raw_choice, blob_choices,
       word->outword);
   }
   set_global_subsubloc_code(SUBSUBLOC_OTHER);
@@ -971,17 +994,17 @@ void match_word_pass2(                 //recog one word
   else {
     if ((word->best_choice->lengths ().length () !=
       word->outword->blob_list ()->length ()) ||
-    (word->best_choice->lengths ().length () != blob_choices.length ())) {
+    (word->best_choice->lengths ().length () != blob_choices->length ())) {
       tprintf
         ("ASSERT FAIL String:\"%s\"; Strlen=%d; #Blobs=%d; #Choices=%d\n",
         word->best_choice->string ().string (),
         word->best_choice->lengths ().length (),
-        word->outword->blob_list ()->length (), blob_choices.length ());
+        word->outword->blob_list ()->length (), blob_choices->length ());
     }
     ASSERT_HOST (word->best_choice->lengths ().length () ==
       word->outword->blob_list ()->length ());
     ASSERT_HOST (word->best_choice->lengths ().length () ==
-      blob_choices.length ());
+      blob_choices->length ());
 
     word->tess_failed = FALSE;
     if (word->word->flag (W_REP_CHAR)) {
@@ -989,37 +1012,43 @@ void match_word_pass2(                 //recog one word
     }
     else {
       fix_quotes (word->best_choice,
-        word->outword, &blob_choices);
+        word->outword, blob_choices);
       if (tessedit_fix_hyphens)
         fix_hyphens (word->best_choice,
-          word->outword, &blob_choices);
+          word->outword, blob_choices);
       /* Dont trust fix_quotes! - though I think I've fixed the bug */
       if ((word->best_choice->lengths ().length () !=
            word->outword->blob_list ()->length ()) ||
           (word->best_choice->lengths ().length () !=
-           blob_choices.length ())) {
+           blob_choices->length ())) {
         #ifndef SECURE_NAMES
         tprintf
           ("POST FIX_QUOTES FAIL String:\"%s\"; Strlen=%d; #Blobs=%d; #Choices=%d\n",
            word->best_choice->string ().string (),
            word->best_choice->lengths ().length (),
            word->outword->blob_list ()->length (),
-           blob_choices.length ());
+           blob_choices->length ());
         #endif
 
       }
       ASSERT_HOST (word->best_choice->lengths ().length () ==
         word->outword->blob_list ()->length ());
       ASSERT_HOST (word->best_choice->lengths ().length () ==
-        blob_choices.length ());
+        blob_choices->length ());
 
       word->tess_accepted = tess_acceptable_word (word->best_choice,
         word->raw_choice);
 
-      make_reject_map (word, &blob_choices, row, 2);
+      make_reject_map (word, blob_choices, row, 2);
     }
   }
-  blob_choices.deep_clear ();
+
+  // Save best choices in the WERD_CHOICE if needed
+  if (blob_choices != &local_blob_choices)
+    word->best_choice->set_blob_choices(blob_choices);
+  else
+    blob_choices->deep_clear();
+
   delete bln_word;
   assert (word->raw_choice != NULL);
 }
@@ -1136,7 +1165,8 @@ void fix_quotes(               //make double quotes
     if (str[offset + choice->lengths()[i]] != '\0' &&
         is_simple_quote(str + offset, choice->lengths()[i]) &&
         is_simple_quote(str + offset + choice->lengths()[i],
-                        choice->lengths()[i + 1])) {
+                        choice->lengths()[i + 1]) &&
+        unicharset.contains_unichar("\"")) {
       str[offset] = '"';                //turn to double
       strcpy (str + offset + 1,
               str + offset + choice->lengths()[i] +
@@ -1252,7 +1282,7 @@ void choice_dump_tester(                           //dump chars in word
                         DENORM *,                  //de-normaliser
                         BOOL8 correct,             //ly segmented
                         char *text,                //correct text
-                        INT32 count,               //chars in text
+                        inT32 count,               //chars in text
                         BLOB_CHOICE_LIST *ratings  //list of results
                        ) {
   STRING choice_file_name;
@@ -1440,7 +1470,7 @@ ACCEPTABLE_WERD_TYPE acceptable_word_string(const char *s,
 
 BOOL8 check_debug_pt(WERD_RES *word, int location) {
   BOOL8 show_map_detail = FALSE;
-  INT16 i;
+  inT16 i;
 
   #ifndef SECURE_NAMES
   if (!test_pt)
@@ -1535,15 +1565,15 @@ BOOL8 check_debug_pt(WERD_RES *word, int location) {
 void set_word_fonts(                 //good chars in word
                     WERD_RES *word,  //word to adapt to //detailed results
                     BLOB_CHOICE_LIST_CLIST *blob_choices) {
-  INT32 index;                   //char index
-  INT32 offset;                  //char offset
+  inT32 index;                   //char index
+  inT32 offset;                  //char offset
   char choice_char[UNICHAR_LEN + 1];    //char from word
-  INT8 config;                   //font of char
+  inT8 config;                   //font of char
                                  //character iterator
   BLOB_CHOICE_LIST_C_IT char_it = blob_choices;
   BLOB_CHOICE_IT choice_it;      //choice iterator
   STATS fonts (0, 32);           //font counters
-  static INT8 italic_table[32] = {
+  static inT8 italic_table[32] = {
     1, -1, 1, -1,
     1, -1, 1, -1,
     1, -1, 1, -1,
@@ -1553,7 +1583,7 @@ void set_word_fonts(                 //good chars in word
     1, -1, 1, -1,
     1, -1, 1, -1
   };
-  static INT8 bold_table[32] = {
+  static inT8 bold_table[32] = {
     1, 1, -1, -1,
     1, 1, -1, -1,
     1, 1, -1, -1,
@@ -1563,7 +1593,7 @@ void set_word_fonts(                 //good chars in word
     1, 1, -1, -1,
     1, 1, -1, -1
   };
-  static INT8 font_table[32] = {
+  static inT8 font_table[32] = {
     2, 2, 2, 2,
     -1, -1, -1, -1,
     0, 0, 0, 0,
@@ -1639,12 +1669,12 @@ void set_word_fonts(                 //good chars in word
 
 void font_recognition_pass(  //good chars in word
                            PAGE_RES_IT &page_res_it) {
-  INT32 length;                  //of word
-  INT32 count;                   //of a feature
-  INT8 doc_font;                 //modal font
-  INT8 doc_font_count;           //modal font
-  INT32 doc_italic;              //total italics
-  INT32 doc_bold;                //total bolds
+  inT32 length;                  //of word
+  inT32 count;                   //of a feature
+  inT8 doc_font;                 //modal font
+  inT8 doc_font_count;           //modal font
+  inT32 doc_italic;              //total italics
+  inT32 doc_bold;                //total bolds
   ROW_RES *row = NULL;           //current row
   WERD_RES *word;                //current word
   STATS fonts (0, 32);           //font counters
@@ -1736,17 +1766,17 @@ void font_recognition_pass(  //good chars in word
     count = word->italic;
     if (count < 0)
       count = -count;
-    if (!(count == length || length > 3 && count >= length * 3 / 4))
+    if (!(count == length || (length > 3 && count >= length * 3 / 4)))
       word->italic = doc_italic > 0 ? 1 : -1;
 
     count = word->bold;
     if (count < 0)
       count = -count;
-    if (!(count == length || length > 3 && count >= length * 3 / 4))
+    if (!(count == length || (length > 3 && count >= length * 3 / 4)))
       word->bold = doc_bold > 0 ? 1 : -1;
 
     count = word->font1_count;
-    if (!(count == length || length > 3 && count >= length * 3 / 4)) {
+    if (!(count == length || (length > 3 && count >= length * 3 / 4))) {
       word->font1 = doc_font;
       word->font1_count = doc_font_count;
     }
@@ -1765,8 +1795,8 @@ void font_recognition_pass(  //good chars in word
 void add_in_one_row(               //good chars in word
                     ROW_RES *row,  //current row
                     STATS *fonts,  //font stats
-                    INT8 *italic,  //output count
-                    INT8 *bold     //output count
+                    inT8 *italic,  //output count
+                    inT8 *bold     //output count
                    ) {
   WERD_RES *word;                //current word
   WERD_RES_IT word_it = &row->word_res_list;
@@ -1792,14 +1822,14 @@ void add_in_one_row(               //good chars in word
 
 void find_modal_font(                  //good chars in word
                      STATS *fonts,     //font stats
-                     INT8 *font_out,   //output font
-                     INT8 *font_count  //output count
+                     inT8 *font_out,   //output font
+                     inT8 *font_count  //output count
                     ) {
-  INT8 font;                     //font index
-  INT32 count;                   //pile couat
+  inT8 font;                     //font index
+  inT32 count;                   //pile couat
 
   if (fonts->get_total () > 0) {
-    font = (INT8) fonts->mode ();
+    font = (inT8) fonts->mode ();
     *font_out = font;
     count = fonts->pile_count (font);
     *font_count = count < MAX_INT8 ? count : MAX_INT8;
