@@ -30,11 +30,12 @@ class BLOB_CHOICE:public ELIST_LINK
   public:
     BLOB_CHOICE() {  //empty
     }
-    BLOB_CHOICE(                    //constructor
-                char *src_unichar,  //character
-                float src_rating,   //rating
-                float src_cert,     //certainty
-                INT8 src_config);   //config (font)
+    BLOB_CHOICE(                      //constructor
+                char *src_unichar,    //character
+                float src_rating,     //rating
+                float src_cert,       //certainty
+                inT8 src_config,      //config (font)
+                const char* script);  //script
 
     void set_unichar(  //change it
                    char *newunichar) {
@@ -49,9 +50,25 @@ class BLOB_CHOICE:public ELIST_LINK
       blob_certainty = newrat;
     }
     void set_config(  //change it
-                    INT8 newfont) {
+                    inT8 newfont) {
       blob_config = newfont;
     }
+    void set_script(  //change it
+                      //newscript is not copied and the structure does not take
+                      //the ownership of newscript.
+                      //Thus, newscript must outlive the BLOB_CHOICE structure.
+                      //The rationale is that the script is obtained from
+                      //unicharset that manage itself ownership of returned
+                      //pointers.
+                    const char* newscript) {
+      blob_script = newscript;
+    }
+
+    static BLOB_CHOICE* deep_copy(const BLOB_CHOICE* src) {
+      BLOB_CHOICE* choice = new BLOB_CHOICE;
+      *choice = *src;
+      return choice;
+    }
 
     const char* const unichar() const {  //access function
       return blob_unichar;
@@ -62,16 +79,20 @@ class BLOB_CHOICE:public ELIST_LINK
     float certainty() const {  //access function
       return blob_certainty;
     }
-    INT8 config() const {  //access function
+    inT8 config() const {  //access function
       return blob_config;
     }
+    const char* script() const {  //access function
+      return blob_script;
+    }
 
     NEWDELETE private:
     char blob_unichar[UNICHAR_LEN + 1]; //unichar
     char blob_config;                   //char config (font)
-    INT16 junk2;
+    inT16 junk2;
     float blob_rating;                  //size related
     float blob_certainty;               //absolute
+    const char* blob_script;
 };
 
                                  //make them listable
@@ -95,14 +116,21 @@ WERD_CHOICE
 {
   public:
     WERD_CHOICE() {  //empty
+      word_string = NULL;
+      word_lengths = NULL;
+      word_rating = 0.0;
+      word_certainty = 0.0;
+      word_permuter = 0;
+      word_blob_choices = NULL;
     }
     WERD_CHOICE(                         //constructor
                 const char *src_string,  //word string
                 const char *src_lengths, //unichar lengths
                 float src_rating,        //rating
                 float src_cert,          //certainty
-                UINT8 src_permuter);     //permuter code
+                uinT8 src_permuter);     //permuter code
 
+    ~WERD_CHOICE();
                                  //access function
     const STRING &string() const {
       return word_string;
@@ -118,23 +146,40 @@ WERD_CHOICE
     float certainty() const {  //access function
       return word_certainty;
     }
-    UINT8 permuter() const {  //access function
+    void set_certainty(  //change it
+        float new_val) {
+      word_certainty = new_val;
+    }
+    uinT8 permuter() const {  //access function
       return word_permuter;
     }
     void set_permuter(  //Override
-                      UINT8 perm) {
+                      uinT8 perm) {
       word_permuter = perm;
     }
 
+    BLOB_CHOICE_LIST_CLIST* blob_choices() {
+      return word_blob_choices;
+    }
+
+    void set_blob_choices(BLOB_CHOICE_LIST_CLIST *blob_choices);
+
     WERD_CHOICE & operator+= (   //concatanate
       const WERD_CHOICE & second);//second on first
 
+    WERD_CHOICE& operator= (const WERD_CHOICE& source);
+
     NEWDELETE private:
     STRING word_string;          //text
     STRING word_lengths;         //unichar lengths for the string
     float word_rating;           //size related
     float word_certainty;        //absolute
-    UINT8 word_permuter;         //permuter code
+    uinT8 word_permuter;         //permuter code
+    BLOB_CHOICE_LIST_CLIST *word_blob_choices; //best choices for each blob
+
+ private:
+
+    void delete_blob_choices();
 };
 
 CLISTIZEH (WERD_CHOICE)
@@ -148,6 +193,6 @@ void print_ratings_info(                           //print summary info
                        );
 typedef void (*POLY_MATCHER) (PBLOB *, PBLOB *, PBLOB *, WERD *,
 DENORM *, BLOB_CHOICE_LIST &);
-typedef void (*POLY_TESTER) (PBLOB *, DENORM *, BOOL8, char *, INT32,
+typedef void (*POLY_TESTER) (PBLOB *, DENORM *, BOOL8, char *, inT32,
 BLOB_CHOICE_LIST *);
 #endif
