@@ -70,7 +70,7 @@ void (*zapper) (ELIST_LINK *)) {
   ELIST_LINK *ptr;
   ELIST_LINK *next;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::internal_clear", ABORT, NULL);
   #endif
@@ -87,36 +87,6 @@ void (*zapper) (ELIST_LINK *)) {
   }
 }
 
-
-/***********************************************************************
- *							ELIST::internal_deep_copy
- *
- *  Used during explict deep copy of a list.  The "copier" function passed
- *  allows each element to be correctly deep copied (assuming that each class
- *  in the inheritance hierarchy does properly deep copies its members).  The
- *  function passing technique is as for "internal_clear".
- **********************************************************************/
-
-void
-                                 //ptr to copier functn
-ELIST::internal_deep_copy (ELIST_LINK * (*copier) (ELIST_LINK *),
-const ELIST * list) {            //list being copied
-  ELIST_ITERATOR from_it ((ELIST *) list);
-  ELIST_ITERATOR to_it(this);
-
-  #ifdef _DEBUG
-  if (!this)
-    NULL_OBJECT.error ("ELIST::internal_deep_copy", ABORT, NULL);
-  if (!list)
-    BAD_PARAMETER.error ("ELIST::internal_deep_copy", ABORT,
-      "source list is NULL");
-  #endif
-
-  for (from_it.mark_cycle_pt (); !from_it.cycled_list (); from_it.forward ())
-    to_it.add_after_then_move (copier (from_it.data ()));
-}
-
-
 /***********************************************************************
  *							ELIST::assign_to_sublist
  *
@@ -136,7 +106,7 @@ void ELIST::assign_to_sublist(                           //to this list
   const ERRCODE LIST_NOT_EMPTY =
     "Destination list must be empty before extracting a sublist";
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::assign_to_sublist", ABORT, NULL);
   #endif
@@ -158,7 +128,7 @@ inT32 ELIST::length() {  //count elements
   ELIST_ITERATOR it(this);
   inT32 count = 0;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::length", ABORT, NULL);
   #endif
@@ -187,7 +157,7 @@ const void *, const void *)) {
   ELIST_LINK **current;
   inT32 i;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::sort", ABORT, NULL);
   #endif
@@ -215,6 +185,36 @@ const void *, const void *)) {
   free(base);
 }
 
+// Assuming list has been sorted already, insert new_link to
+// keep the list sorted according to the same comparison function.
+// Comparision function is the same as used by sort, i.e. uses double
+// indirection. Time is O(1) to add to beginning or end.
+// Time is linear to add pre-sorted items to an empty list.
+void ELIST::add_sorted(int comparator(const void*, const void*),
+                       ELIST_LINK* new_link) {
+  // Check for adding at the end.
+  if (last == NULL || comparator(&last, &new_link) < 0) {
+    if (last == NULL) {
+      new_link->next = new_link;
+    } else {
+      new_link->next = last->next;
+      last->next = new_link;
+    }
+    last = new_link;
+  } else {
+    // Need to use an iterator.
+    ELIST_ITERATOR it(this);
+    for (it.mark_cycle_pt(); !it.cycled_list(); it.forward()) {
+      ELIST_LINK* link = it.data();
+      if (comparator(&link, &new_link) > 0)
+        break;
+    }
+    if (it.cycled_list())
+      it.add_to_end(new_link);
+    else
+      it.add_before_then_move(new_link);
+  }
+}
 
 /***********************************************************************
  *							ELIST::prep_serialise
@@ -229,7 +229,7 @@ void ELIST::prep_serialise() {
   ELIST_ITERATOR this_it(this);
   inT32 count = 0;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::prep_serialise", ABORT, NULL);
   #endif
@@ -257,7 +257,7 @@ ELIST::internal_dump (FILE * f,
 void element_serialiser (FILE *, ELIST_LINK *)) {
   ELIST_ITERATOR this_it(this);
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::internal_dump", ABORT, NULL);
   #endif
@@ -285,7 +285,7 @@ ELIST_LINK * element_de_serialiser (FILE *)) {
   ELIST_ITERATOR this_it;
   ELIST_LINK *de_serialised_element;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST::internal_de_dump", ABORT, NULL);
   #endif
@@ -314,7 +314,7 @@ ELIST_LINK * element_de_serialiser (FILE *)) {
  **********************************************************************/
 
 ELIST_LINK *ELIST_ITERATOR::forward() {
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST_ITERATOR::forward", ABORT, NULL);
   if (!list)
@@ -327,21 +327,21 @@ ELIST_LINK *ELIST_ITERATOR::forward() {
                                  //set previous
     prev = current;
     started_cycling = TRUE;
-  }
-  else {
+    // In case next is deleted by another iterator, get next from current.
+    current = current->next;
+  } else {
     if (ex_current_was_cycle_pt)
       cycle_pt = next;
+    current = next;
   }
-  current = next;
   next = current->next;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!current)
     NULL_DATA.error ("ELIST_ITERATOR::forward", ABORT, NULL);
   if (!next)
     NULL_NEXT.error ("ELIST_ITERATOR::forward", ABORT,
-      "This is: %i  Current is: %i",
-      (int) this, (int) current);
+                     "This is: %p  Current is: %p", this, current);
   #endif
   return current;
 }
@@ -359,7 +359,7 @@ ELIST_LINK *ELIST_ITERATOR::data_relative(                //get data + or - ...
                                           inT8 offset) {  //offset from current
   ELIST_LINK *ptr;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST_ITERATOR::data_relative", ABORT, NULL);
   if (!list)
@@ -376,7 +376,7 @@ ELIST_LINK *ELIST_ITERATOR::data_relative(                //get data + or - ...
   else
     for (ptr = current ? current : prev; offset-- > 0; ptr = ptr->next);
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!ptr)
     NULL_DATA.error ("ELIST_ITERATOR::data_relative", ABORT, NULL);
   #endif
@@ -394,7 +394,7 @@ ELIST_LINK *ELIST_ITERATOR::data_relative(                //get data + or - ...
  **********************************************************************/
 
 ELIST_LINK *ELIST_ITERATOR::move_to_last() {
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST_ITERATOR::move_to_last", ABORT, NULL);
   if (!list)
@@ -425,7 +425,7 @@ void ELIST_ITERATOR::exchange(                             //positions of 2 link
 
   ELIST_LINK *old_current;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST_ITERATOR::exchange", ABORT, NULL);
   if (!list)
@@ -520,7 +520,7 @@ void ELIST_ITERATOR::exchange(                             //positions of 2 link
 
 ELIST_LINK *ELIST_ITERATOR::extract_sublist(                             //from this current
                                             ELIST_ITERATOR *other_it) {  //to other current
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   const ERRCODE BAD_EXTRACTION_PTS =
     "Can't extract sublist from points on different lists";
   const ERRCODE DONT_EXTRACT_DELETED =
@@ -531,7 +531,7 @@ ELIST_LINK *ELIST_ITERATOR::extract_sublist(                             //from
   ELIST_ITERATOR temp_it = *this;
   ELIST_LINK *end_of_new_list;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST_ITERATOR::extract_sublist", ABORT, NULL);
   if (!other_it)
