@@ -46,7 +46,7 @@ void (*zapper) (ELIST2_LINK *)) {
   ELIST2_LINK *ptr;
   ELIST2_LINK *next;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::internal_clear", ABORT, NULL);
   #endif
@@ -63,36 +63,6 @@ void (*zapper) (ELIST2_LINK *)) {
   }
 }
 
-
-/***********************************************************************
- *							ELIST2::internal_deep_copy
- *
- *  Used during explict deep copy of a list.  The "copier" function passed
- *  allows each element to be correctly deep copied (assuming that each class
- *  in the inheritance hierarchy does properly deep copies its members).  The
- *  function passing technique is as for "internal_clear".
- **********************************************************************/
-
-void
-                                 //ptr to copier functn
-ELIST2::internal_deep_copy (ELIST2_LINK * (*copier) (ELIST2_LINK *),
-const ELIST2 * list) {           //list being copied
-  ELIST2_ITERATOR from_it ((ELIST2 *) list);
-  ELIST2_ITERATOR to_it(this);
-
-  #ifdef _DEBUG
-  if (!this)
-    NULL_OBJECT.error ("ELIST2::internal_deep_copy", ABORT, NULL);
-  if (!list)
-    BAD_PARAMETER.error ("ELIST2::internal_deep_copy", ABORT,
-      "source list is NULL");
-  #endif
-
-  for (from_it.mark_cycle_pt (); !from_it.cycled_list (); from_it.forward ())
-    to_it.add_after_then_move (copier (from_it.data ()));
-}
-
-
 /***********************************************************************
  *							ELIST2::assign_to_sublist
  *
@@ -112,7 +82,7 @@ void ELIST2::assign_to_sublist(                            //to this list
   const ERRCODE LIST_NOT_EMPTY =
     "Destination list must be empty before extracting a sublist";
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::assign_to_sublist", ABORT, NULL);
   #endif
@@ -134,7 +104,7 @@ inT32 ELIST2::length() {  //count elements
   ELIST2_ITERATOR it(this);
   inT32 count = 0;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::length", ABORT, NULL);
   #endif
@@ -163,7 +133,7 @@ const void *, const void *)) {
   ELIST2_LINK **current;
   inT32 i;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::sort", ABORT, NULL);
   #endif
@@ -191,6 +161,39 @@ const void *, const void *)) {
   free(base);
 }
 
+// Assuming list has been sorted already, insert new_link to
+// keep the list sorted according to the same comparison function.
+// Comparision function is the same as used by sort, i.e. uses double
+// indirection. Time is O(1) to add to beginning or end.
+// Time is linear to add pre-sorted items to an empty list.
+void ELIST2::add_sorted(int comparator(const void*, const void*),
+                        ELIST2_LINK* new_link) {
+  // Check for adding at the end.
+  if (last == NULL || comparator(&last, &new_link) < 0) {
+    if (last == NULL) {
+      new_link->next = new_link;
+      new_link->prev = new_link;
+    } else {
+      new_link->next = last->next;
+      new_link->prev = last;
+      last->next = new_link;
+      new_link->next->prev = new_link;
+    }
+    last = new_link;
+  } else {
+    // Need to use an iterator.
+    ELIST2_ITERATOR it(this);
+    for (it.mark_cycle_pt(); !it.cycled_list(); it.forward()) {
+      ELIST2_LINK* link = it.data();
+      if (comparator(&link, &new_link) > 0)
+        break;
+    }
+    if (it.cycled_list())
+      it.add_to_end(new_link);
+    else
+      it.add_before_then_move(new_link);
+  }
+}
 
 /***********************************************************************
  *							ELIST2::prep_serialise
@@ -205,7 +208,7 @@ void ELIST2::prep_serialise() {
   ELIST2_ITERATOR this_it(this);
   inT32 count = 0;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::prep_serialise", ABORT, NULL);
   #endif
@@ -233,7 +236,7 @@ ELIST2::internal_dump (FILE * f,
 void element_serialiser (FILE *, ELIST2_LINK *)) {
   ELIST2_ITERATOR this_it(this);
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::internal_dump", ABORT, NULL);
   #endif
@@ -261,7 +264,7 @@ ELIST2_LINK * element_de_serialiser (FILE *)) {
   ELIST2_ITERATOR this_it;
   ELIST2_LINK *de_serialised_element;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2::internal_de_dump", ABORT, NULL);
   #endif
@@ -292,7 +295,7 @@ ELIST2_LINK * element_de_serialiser (FILE *)) {
  **********************************************************************/
 
 ELIST2_LINK *ELIST2_ITERATOR::forward() {
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::forward", ABORT, NULL);
   if (!list)
@@ -305,21 +308,22 @@ ELIST2_LINK *ELIST2_ITERATOR::forward() {
                                  //set previous
     prev = current;
     started_cycling = TRUE;
+    // In case next is deleted by another iterator, get it from the current.
+    current = current->next;
   }
   else {
     if (ex_current_was_cycle_pt)
       cycle_pt = next;
+    current = next;
   }
-  current = next;
   next = current->next;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!current)
     NULL_DATA.error ("ELIST2_ITERATOR::forward", ABORT, NULL);
   if (!next)
     NULL_NEXT.error ("ELIST2_ITERATOR::forward", ABORT,
-      "This is: %i  Current is: %i",
-      (int) this, (int) current);
+                     "This is: %p  Current is: %p", this, current);
   #endif
   return current;
 }
@@ -333,7 +337,7 @@ ELIST2_LINK *ELIST2_ITERATOR::forward() {
  **********************************************************************/
 
 ELIST2_LINK *ELIST2_ITERATOR::backward() {
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::backward", ABORT, NULL);
   if (!list)
@@ -346,21 +350,21 @@ ELIST2_LINK *ELIST2_ITERATOR::backward() {
                                  //set previous
     next = current;
     started_cycling = TRUE;
-  }
-  else {
+    // In case prev is deleted by another iterator, get it from current.
+    current = current->prev;
+  } else {
     if (ex_current_was_cycle_pt)
       cycle_pt = prev;
+    current = prev;
   }
-  current = prev;
   prev = current->prev;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!current)
     NULL_DATA.error ("ELIST2_ITERATOR::backward", ABORT, NULL);
   if (!prev)
     NULL_PREV.error ("ELIST2_ITERATOR::backward", ABORT,
-      "This is: %i  Current is: %i",
-      (int) this, (int) current);
+      "This is: %p  Current is: %p", this, current);
   #endif
   return current;
 }
@@ -377,7 +381,7 @@ ELIST2_LINK *ELIST2_ITERATOR::data_relative(                //get data + or - ..
                                             inT8 offset) {  //offset from current
   ELIST2_LINK *ptr;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::data_relative", ABORT, NULL);
   if (!list)
@@ -391,7 +395,7 @@ ELIST2_LINK *ELIST2_ITERATOR::data_relative(                //get data + or - ..
   else
     for (ptr = current ? current : prev; offset-- > 0; ptr = ptr->next);
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!ptr)
     NULL_DATA.error ("ELIST2_ITERATOR::data_relative", ABORT, NULL);
   #endif
@@ -417,7 +421,7 @@ void ELIST2_ITERATOR::exchange(                              //positions of 2 li
 
   ELIST2_LINK *old_current;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::exchange", ABORT, NULL);
   if (!list)
@@ -524,7 +528,7 @@ void ELIST2_ITERATOR::exchange(                              //positions of 2 li
 
 ELIST2_LINK *ELIST2_ITERATOR::extract_sublist(                              //from this current
                                               ELIST2_ITERATOR *other_it) {  //to other current
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   const ERRCODE BAD_EXTRACTION_PTS =
     "Can't extract sublist from points on different lists";
   const ERRCODE DONT_EXTRACT_DELETED =
@@ -535,7 +539,7 @@ ELIST2_LINK *ELIST2_ITERATOR::extract_sublist(                              //fr
   ELIST2_ITERATOR temp_it = *this;
   ELIST2_LINK *end_of_new_list;
 
-  #ifdef _DEBUG
+  #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::extract_sublist", ABORT, NULL);
   if (!other_it)
