@@ -70,7 +70,7 @@ class DLLSYM ERRCODE             //error handler class
   public:
     void error (                 //error print function
       const char *caller,        //function location
-      INT8 action,               //action to take
+      inT8 action,               //action to take
       const char *format, ...    //fprintf format
       ) const;
     ERRCODE(const char *string) {
@@ -82,7 +82,7 @@ const ERRCODE ASSERT_FAILED = "Assert failed";
 
 #define ASSERT_HOST(x) if (!(x))										\
 {																			\
-	ASSERT_FAILED.error(#x,TESSLOG,"in file %s, line %d",		\
+	ASSERT_FAILED.error(#x,ABORT,"in file %s, line %d",		\
 		__FILE__,__LINE__);											\
 }
 
