@@ -45,7 +45,7 @@ enum Ranks {
   RANK_INT  = 0,
   RANK_LONG = 1,
   RANK_LONGLONG = 2,
-  RANK_PTR      = INT_MAX // Special value used for pointers
+  RANK_PTR      = 3 // Special value used for pointers
 };
 
 const enum Ranks kMinRank = RANK_CHAR;
@@ -231,7 +231,7 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
   int q = 0;
   uintmax_t val = 0;
   int rank = RANK_INT;    // Default rank
-  unsigned int width = UINT_MAX;
+  unsigned int width = ~0;
   int base;
   int flags = 0;
   enum {
@@ -260,7 +260,7 @@ int vfscanf(FILE* stream, const char *format, va_list ap)
       case ST_NORMAL:
         if (ch == '%') {
           state = ST_FLAGS;
-          flags = 0; rank = RANK_INT; width = UINT_MAX;
+          flags = 0; rank = RANK_INT; width = ~0;
         } else if (isspace(static_cast<unsigned char>(ch))) {
           SkipSpace(stream);
         } else {
