@@ -23,12 +23,13 @@
 #include "callcpp.h"
 #include "danerror.h"
 #include "freelist.h"
+#include "scanutils.h"
 
 /**----------------------------------------------------------------------------
               Public Code
 ----------------------------------------------------------------------------**/
 /*---------------------------------------------------------------------------*/
-BOOL8 AddFeature(FEATURE_SET FeatureSet, FEATURE Feature) { 
+BOOL8 AddFeature(FEATURE_SET FeatureSet, FEATURE Feature) {
 /*
  **	Parameters:
  **		FeatureSet	set of features to add Feature to
@@ -42,18 +43,20 @@ BOOL8 AddFeature(FEATURE_SET FeatureSet, FEATURE Feature) {
  **	Exceptions: none
  **	History: Tue May 22 17:22:23 1990, DSJ, Created.
  */
-  if (NumFeaturesIn (FeatureSet) >= MaxNumFeaturesIn (FeatureSet))
+  if (FeatureSet->NumFeatures >= FeatureSet->MaxNumFeatures) {
+    FreeFeature(Feature);
     return (FALSE);
+  }
 
-  FeatureIn (FeatureSet, NumFeaturesIn (FeatureSet)) = Feature;
-  NumFeaturesIn (FeatureSet)++;
+  FeatureSet->Features[FeatureSet->NumFeatures] = Feature;
+  FeatureSet->NumFeatures++;
   return (TRUE);
 
 }                                /* AddFeature */
 
 
 /*---------------------------------------------------------------------------*/
-void DefaultInitFXVars() { 
+void DefaultInitFXVars() {
 /*
  **	Parameters: none
  **	Globals: none
@@ -68,7 +71,7 @@ void DefaultInitFXVars() {
 
 
 /*---------------------------------------------------------------------------*/
-void FreeFeature(FEATURE Feature) { 
+void FreeFeature(FEATURE Feature) {
 /*
  **	Parameters:
  **		Feature		feature to be deallocated.
@@ -80,7 +83,7 @@ void FreeFeature(FEATURE Feature) {
  */
   if (Feature) {
     c_free_struct (Feature, sizeof (FEATURE_STRUCT)
-      + sizeof (FLOAT32) * (NumParamsIn (Feature) - 1),
+      + sizeof (FLOAT32) * (Feature->Type->NumParams - 1),
       "sizeof(FEATURE_STRUCT)+sizeof(FLOAT32)*(NumParamsIn(Feature)-1)");
   }
 
@@ -88,7 +91,7 @@ void FreeFeature(FEATURE Feature) {
 
 
 /*---------------------------------------------------------------------------*/
-void FreeFeatureSet(FEATURE_SET FeatureSet) { 
+void FreeFeatureSet(FEATURE_SET FeatureSet) {
 /*
  **	Parameters:
  **		FeatureSet	set of features to be freed
@@ -103,15 +106,15 @@ void FreeFeatureSet(FEATURE_SET FeatureSet) {
   int i;
 
   if (FeatureSet) {
-    for (i = 0; i < NumFeaturesIn (FeatureSet); i++)
-      FreeFeature (FeatureIn (FeatureSet, i));
-    memfree(FeatureSet); 
+    for (i = 0; i < FeatureSet->NumFeatures; i++)
+      FreeFeature (FeatureSet->Features[i]);
+    memfree(FeatureSet);
   }
 }                                /* FreeFeatureSet */
 
 
 /*---------------------------------------------------------------------------*/
-FEATURE NewFeature(FEATURE_DESC FeatureDesc) { 
+FEATURE NewFeature(FEATURE_DESC FeatureDesc) {
 /*
  **	Parameters:
  **		FeatureDesc	description of feature to be created.
@@ -124,18 +127,18 @@ FEATURE NewFeature(FEATURE_DESC FeatureDesc) {
  */
   FEATURE Feature;
 
-  Feature = (FEATURE) c_alloc_struct (sizeof (FEATURE_STRUCT) +
+  Feature = (FEATURE) alloc_struct (sizeof (FEATURE_STRUCT) +
     (FeatureDesc->NumParams - 1) *
     sizeof (FLOAT32),
     "sizeof(FEATURE_STRUCT)+sizeof(FLOAT32)*(NumParamsIn(Feature)-1)");
-  TypeOf (Feature) = FeatureDesc;
+  Feature->Type = FeatureDesc;
   return (Feature);
 
 }                                /* NewFeature */
 
 
 /*---------------------------------------------------------------------------*/
-FEATURE_SET NewFeatureSet(int NumFeatures) { 
+FEATURE_SET NewFeatureSet(int NumFeatures) {
 /*
  **	Parameters:
  **		NumFeatures	maximum # of features to be put in feature set
@@ -150,15 +153,15 @@ FEATURE_SET NewFeatureSet(int NumFeatures) {
 
   FeatureSet = (FEATURE_SET) Emalloc (sizeof (FEATURE_SET_STRUCT) +
     (NumFeatures - 1) * sizeof (FEATURE));
-  MaxNumFeaturesIn (FeatureSet) = NumFeatures;
-  NumFeaturesIn (FeatureSet) = 0;
+  FeatureSet->MaxNumFeatures = NumFeatures;
+  FeatureSet->NumFeatures = 0;
   return (FeatureSet);
 
 }                                /* NewFeatureSet */
 
 
 /*---------------------------------------------------------------------------*/
-FEATURE ReadFeature(FILE *File, FEATURE_DESC FeatureDesc) { 
+FEATURE ReadFeature(FILE *File, FEATURE_DESC FeatureDesc) {
 /*
  **	Parameters:
  **		File		open text file to read feature from
@@ -178,8 +181,8 @@ FEATURE ReadFeature(FILE *File, FEATURE_DESC FeatureDesc) {
   int i;
 
   Feature = NewFeature (FeatureDesc);
-  for (i = 0; i < NumParamsIn (Feature); i++) {
-    if (fscanf (File, "%f", &(ParamOf (Feature, i))) != 1)
+  for (i = 0; i < Feature->Type->NumParams; i++) {
+    if (fscanf (File, "%f", &(Feature->Params[i])) != 1)
       DoError (ILLEGAL_FEATURE_PARAM, "Illegal feature parameter spec");
   }
   return (Feature);
@@ -188,7 +191,7 @@ FEATURE ReadFeature(FILE *File, FEATURE_DESC FeatureDesc) {
 
 
 /*---------------------------------------------------------------------------*/
-FEATURE_SET ReadFeatureSet(FILE *File, FEATURE_DESC FeatureDesc) { 
+FEATURE_SET ReadFeatureSet(FILE *File, FEATURE_DESC FeatureDesc) {
 /*
  **	Parameters:
  **		File		open text file to read new feature set from
@@ -220,7 +223,7 @@ FEATURE_SET ReadFeatureSet(FILE *File, FEATURE_DESC FeatureDesc) {
 
 
 /*---------------------------------------------------------------------------*/
-void WriteFeature(FILE *File, FEATURE Feature) { 
+void WriteFeature(FILE *File, FEATURE Feature) {
 /*
  **	Parameters:
  **		File		open text file to write Feature to
@@ -238,15 +241,15 @@ void WriteFeature(FILE *File, FEATURE Feature) {
  */
   int i;
 
-  for (i = 0; i < NumParamsIn (Feature); i++)
-    fprintf (File, " %12g", ParamOf (Feature, i));
+  for (i = 0; i < Feature->Type->NumParams; i++)
+    fprintf (File, " %12g", Feature->Params[i]);
   fprintf (File, "\n");
 
 }                                /* WriteFeature */
 
 
 /*---------------------------------------------------------------------------*/
-void WriteFeatureSet(FILE *File, FEATURE_SET FeatureSet) { 
+void WriteFeatureSet(FILE *File, FEATURE_SET FeatureSet) {
 /*
  **	Parameters:
  **		File		open text file to write FeatureSet to
@@ -263,15 +266,15 @@ void WriteFeatureSet(FILE *File, FEATURE_SET FeatureSet) {
   int i;
 
   if (FeatureSet) {
-    fprintf (File, "%d\n", NumFeaturesIn (FeatureSet));
-    for (i = 0; i < NumFeaturesIn (FeatureSet); i++)
-      WriteFeature (File, FeatureIn (FeatureSet, i));
+    fprintf (File, "%d\n", FeatureSet->NumFeatures);
+    for (i = 0; i < FeatureSet->NumFeatures; i++)
+      WriteFeature (File, FeatureSet->Features[i]);
   }
 }                                /* WriteFeatureSet */
 
 
 /*---------------------------------------------------------------------------*/
-void WriteOldParamDesc(FILE *File, FEATURE_DESC FeatureDesc) { 
+void WriteOldParamDesc(FILE *File, FEATURE_DESC FeatureDesc) {
 /*
  **	Parameters:
  **		File		open text file to write FeatureDesc to
