@@ -62,6 +62,7 @@ void check_for_words (EDGE_ARRAY dawg,
                       char       *filename) {
   FILE       *word_file;
   char       string [CHARS_PER_LINE];
+  int misses = 0;
 
   word_file = open_file (filename, "r");
 
@@ -86,7 +87,8 @@ void check_for_words (EDGE_ARRAY dawg,
         debug = 1;
       }
       else {
-        match_words (dawg, string, 0, 0);
+        if (!match_words (dawg, string, 0, 0))
+          ++misses;
       }
     }
 
@@ -96,6 +98,8 @@ void check_for_words (EDGE_ARRAY dawg,
     }
   }
   fclose (word_file);
+  // Make sure the user sees this with fprintf instead of tprintf.
+  fprintf(stderr, "Number of lost words=%d\n", misses);
 }
 
 #if 0
@@ -159,7 +163,7 @@ int main (argc, argv)
 * in this string are wildcards.
 **********************************************************************/
 
-void match_words (EDGE_ARRAY  dawg,
+bool match_words (EDGE_ARRAY  dawg,
                   char        *string,
                   inT32         index,
                   NODE_REF    node) {
@@ -167,26 +171,32 @@ void match_words (EDGE_ARRAY  dawg,
   inT32        word_end;
 
   if (string[index] == '*') {
+    bool any_matched = false;
     edge = node;
     do {
       string[index] = edge_letter (dawg, edge);
-      match_words (dawg, string, index, node);
+      if (match_words (dawg, string, index, node))
+        any_matched = true;
     } edge_loop (dawg, edge);
     string[index] = '*';
+    return any_matched;
   }
   else {
     word_end = (string[index+1] == (char) 0);
-    edge = edge_char_of (dawg, node, string[index], word_end);
+    edge = edge_char_of(dawg, node,
+                        static_cast<unsigned char>(string[index]), word_end);
     if (edge != NO_EDGE) {                         /* Normal edge in DAWG */
       node = next_node (dawg, edge);
       if (word_end) {
         printf ("%s\n", string);
+        return true;
       }
       else if (node != 0) {
-        match_words (dawg, string, index+1, node);
+        return match_words (dawg, string, index+1, node);
       }
     }
   }
+  return false;
 }
 
 
