@@ -38,6 +38,7 @@ EXTERN BOOL_VAR (textord_oldbl_merge_parts, TRUE, "Merge suspect partitions");
 EXTERN BOOL_VAR (oldbl_corrfix, TRUE, "Improve correlation of heights");
 EXTERN BOOL_VAR (oldbl_xhfix, FALSE,
 "Fix bug in modes threshold for xheights");
+EXTERN BOOL_VAR(textord_ocropus_mode, FALSE, "Make baselines for ocropus");
 EXTERN double_VAR (oldbl_xhfract, 0.4, "Fraction of est allowed in calc");
 EXTERN INT_VAR (oldbl_holed_losscount, 10,
 "Max lost before fallback line used");
@@ -337,7 +338,7 @@ void find_textlines(                  //get baseline
   float jumplimit;               /*allowed delta change */
   int *xcoords;                  /*useful sample points */
   int *ycoords;                  /*useful sample points */
-  BOX *blobcoords;               /*edges of blob rectangles */
+  TBOX *blobcoords;               /*edges of blob rectangles */
   int blobcount;                 /*no of blobs on line */
   float *ydiffs;                 /*diffs from 1st approx */
   int pointcount;                /*no of coords */
@@ -349,7 +350,7 @@ void find_textlines(                  //get baseline
   partids = (char *) alloc_mem (blobcount * sizeof (char));
   xcoords = (int *) alloc_mem (blobcount * sizeof (int));
   ycoords = (int *) alloc_mem (blobcount * sizeof (int));
-  blobcoords = (BOX *) alloc_mem (blobcount * sizeof (BOX));
+  blobcoords = (TBOX *) alloc_mem (blobcount * sizeof (TBOX));
   ydiffs = (float *) alloc_mem (blobcount * sizeof (float));
 
   lineheight = get_blob_coords (row, (int) block->line_size, blobcoords,
@@ -372,7 +373,7 @@ void find_textlines(                  //get baseline
       xcoords, ycoords, spline, &row->baseline, jumplimit);
 #ifndef GRAPHICS_DISABLED
   if (textord_show_final_rows)
-    row->baseline.plot (to_win, GOLDENROD);
+    row->baseline.plot (to_win, ScrollView::GOLDENROD);
 #endif
   if (blobcount > 1) {
     bestpart = partition_line (blobcoords, blobcount,
@@ -432,8 +433,8 @@ void find_textlines(                  //get baseline
 
 int get_blob_coords(                    //get boxes
                     TO_ROW *row,        //row to use
-                    INT32 lineheight,   //block level
-                    BOX *blobcoords,    //ouput boxes
+                    inT32 lineheight,   //block level
+                    TBOX *blobcoords,    //ouput boxes
                     BOOL8 &holed_line,  //lost a lot of blobs
                     int &outcount       //no of real blobs
                    ) {
@@ -501,7 +502,7 @@ int get_blob_coords(                    //get boxes
 
 void
 make_first_baseline (            //initial approximation
-BOX blobcoords[],                /*blob bounding boxes */
+TBOX blobcoords[],                /*blob bounding boxes */
 int blobcount,                   /*no of blobcoords */
 int xcoords[],                   /*coords for spline */
 int ycoords[],                   /*approximator */
@@ -567,9 +568,9 @@ float jumplimit                  /*guess half descenders */
           y3 = thisy;            /*middle point */
           ycount++;
                                  /*local max */
-          if (ycount >= 3 && (y1 < y2 && y2 >= y3
+          if (ycount >= 3 && ((y1 < y2 && y2 >= y3)
                                  /*local min */
-          || y1 > y2 && y2 <= y3)) {
+          || (y1 > y2 && y2 <= y3))) {
             if (segment < SPLINESIZE - 2) {
                                  /*turning pt */
               xturns[segment] = x2;
@@ -609,9 +610,9 @@ float jumplimit                  /*guess half descenders */
               prevy = yturns[blobindex];
             }
                                  /*bigger max */
-            else if (prevy > minmin + jumplimit && yturns[blobindex] > prevy
+            else if ((prevy > minmin + jumplimit && yturns[blobindex] > prevy)
                                  /*smaller min */
-            || prevy < maxmax - jumplimit && yturns[blobindex] < prevy) {
+            || (prevy < maxmax - jumplimit && yturns[blobindex] < prevy)) {
               xstarts[segment - 1] = xturns[blobindex];
                                  /*improved previous */
               prevy = yturns[blobindex];
@@ -627,7 +628,7 @@ float jumplimit                  /*guess half descenders */
   }
   else {
     *baseline = *spline;         /*copy it */
-    shift = ICOORD (0, (INT16) (blobcoords[0].bottom ()
+    shift = ICOORD (0, (inT16) (blobcoords[0].bottom ()
       - spline->y (blobcoords[0].right ())));
     baseline->move (shift);
   }
@@ -644,7 +645,7 @@ float jumplimit                  /*guess half descenders */
 
 void
 make_holed_baseline (            //initial approximation
-BOX blobcoords[],                /*blob bounding boxes */
+TBOX blobcoords[],                /*blob bounding boxes */
 int blobcount,                   /*no of blobcoords */
 QSPLINE * spline,                /*initial spline */
 QSPLINE * baseline,              /*output spline */
@@ -657,7 +658,7 @@ float gradient                   //of line
   ICOORD shift;                  //shift of spline
 
   LMS lms(blobcount);  //straight baseline
-  INT32 xstarts[2];              //straight line
+  inT32 xstarts[2];              //straight line
   double coeffs[3];
   float c;                       //line parameter
 
@@ -685,7 +686,7 @@ float gradient                   //of line
   - MAXOVERLAP * (rightedge - leftedge)) {
     *baseline = *spline;         /*copy it */
     x = (leftedge + rightedge) / 2.0;
-    shift = ICOORD (0, (INT16) (gradient * x + c - spline->y (x)));
+    shift = ICOORD (0, (inT16) (gradient * x + c - spline->y (x)));
     baseline->move (shift);
   }
 }
@@ -702,7 +703,7 @@ float gradient                   //of line
 
 int
 partition_line (                 //partition blobs
-BOX blobcoords[],                //bounding boxes
+TBOX blobcoords[],                //bounding boxes
 int blobcount,                   /*no of blobs on row */
 int *numparts,                   /*number of partitions */
 char partids[],                  /*partition no of each blob */
@@ -779,7 +780,7 @@ float ydiffs[]                   /*diff from spline */
 
 void
 merge_oldbl_parts (              //partition blobs
-BOX blobcoords[],                //bounding boxes
+TBOX blobcoords[],                //bounding boxes
 int blobcount,                   /*no of blobs on row */
 char partids[],                  /*partition no of each blob */
 int partsizes[],                 /*no in each partition */
@@ -892,7 +893,7 @@ float jumplimit                  /*allowed delta change */
 
 int
 get_ydiffs (                     //evaluate differences
-BOX blobcoords[],                //bounding boxes
+TBOX blobcoords[],                //bounding boxes
 int blobcount,                   /*no of blobs */
 QSPLINE * spline,                /*approximating spline */
 float ydiffs[]                   /*output */
@@ -1070,7 +1071,7 @@ int *partcount                   /*no of partitions */
 
 int
 partition_coords (               //find relevant coords
-BOX blobcoords[],                //bounding boxes
+TBOX blobcoords[],                //bounding boxes
 int blobcount,                   /*no of blobs in row */
 char partids[],                  /*partition no of each blob */
 int bestpart,                    /*best new partition */
@@ -1101,7 +1102,7 @@ int ycoords[]                    /*points to work on */
 
 int
 segment_spline (                 //make xstarts
-BOX blobcoords[],                //boundign boxes
+TBOX blobcoords[],                //boundign boxes
 int blobcount,                   /*no of blobs in row */
 int xcoords[],                   /*points to work on */
 int ycoords[],                   /*points to work on */
@@ -1313,7 +1314,7 @@ int &segments                    //no of segments
         tprintf
           ("Resegmenting spline failed - insufficient pts (%d,%d,%d,%d)\n",
           startindex, centreindex, endindex,
-          (INT32) textord_spline_medianwin);
+          (inT32) textord_spline_medianwin);
       }
     }
     //              else tprintf("Spline step at %d is %g\n",
@@ -1358,7 +1359,7 @@ int coord2, int &segments        //total segments
 void
 find_lesser_parts (              //get descenders
 TO_ROW * row,                    //row to process
-BOX blobcoords[],                //bounding boxes
+TBOX blobcoords[],                //bounding boxes
 int blobcount,                   /*no of blobs */
 char partids[],                  /*partition of each blob */
 int partsizes[],                 /*size of each part */
@@ -1405,7 +1406,7 @@ int bestpart                     /*biggest partition */
 	//by jetsoft divide by zero possible
 		if (partsizes[partition]==0)
 		partsteps[partition]=0;
-       else 
+       else
 		partsteps[partition] /= partsizes[partition];
 	//
 
@@ -1443,7 +1444,7 @@ int bestpart                     /*biggest partition */
 void
 old_first_xheight (              //the wiseowl way
 TO_ROW * row,                    /*current row */
-BOX blobcoords[],                /*blob bounding boxes */
+TBOX blobcoords[],                /*blob bounding boxes */
 int initialheight,               //initial guess
 int blobcount,                   /*blobs in blobcoords */
 QSPLINE * baseline,              /*established */
@@ -1528,7 +1529,7 @@ float jumplimit                  /*min ascender height */
 void
 make_first_xheight (             //find xheight
 TO_ROW * row,                    /*current row */
-BOX blobcoords[],                /*blob bounding boxes */
+TBOX blobcoords[],                /*blob bounding boxes */
 int lineheight,                  //initial guess
 int init_lineheight,             //block level guess
 int blobcount,                   /*blobs in blobcoords */
@@ -1557,8 +1558,9 @@ float jumplimit                  /*min ascender height */
         blobcoords[blobindex].right ()) / 2;
     float base = baseline->y(xcenter);
     float bottomdiff = fabs(base - blobcoords[blobindex].bottom());
-    int strength = bottomdiff <= kBaselineTouch ? kGoodStrength : 1;
-    int height = static_cast<int>(blobcoords[blobindex].top () - base);
+    int strength = textord_ocropus_mode &&
+                   bottomdiff <= kBaselineTouch ? kGoodStrength : 1;
+    int height = static_cast<int>(blobcoords[blobindex].top () - base + 0.5);
     if (blobcoords[blobindex].height () > init_lineheight * kMinHeight) {
       if (height > lineheight * oldbl_xhfract
         && height > textord_min_xheight) {
@@ -1606,7 +1608,8 @@ float jumplimit                  /*min ascender height */
  * input distribution.
  **********************************************************************/
 
-const int kMinModeFactor = 32;
+const int kMinModeFactorOcropus = 32;
+const int kMinModeFactor = 12;
 
 void
 find_top_modes (                 //get modes
@@ -1620,6 +1623,8 @@ int modelist[], int modenum      //no of modes to get
   int i;
   int mode;
   int total_max = 0;
+  int mode_factor = textord_ocropus_mode ?
+                    kMinModeFactorOcropus : kMinModeFactor;
 
   for (mode_count = 0; mode_count < modenum; mode_count++) {
     mode = 0;
@@ -1634,7 +1639,7 @@ int modelist[], int modenum      //no of modes to get
     last_i = mode;
     last_max = stats->pile_count (last_i);
     total_max += last_max;
-    if (last_max <= total_max / kMinModeFactor)
+    if (last_max <= total_max / mode_factor)
       mode = 0;
     modelist[mode_count] = mode;
   }
@@ -1666,8 +1671,9 @@ void pick_x_height(TO_ROW * row,                    //row to do
       /* Check for two modes */
       if (modelist[x] && modelist[y] &&
           heightstat->pile_count (modelist[x]) > mode_threshold &&
-          MIN(rights[modelist[x]], rights[modelist[y]]) >
-          MAX(lefts[modelist[x]], lefts[modelist[y]])) {
+          (!textord_ocropus_mode ||
+           MIN(rights[modelist[x]], rights[modelist[y]]) >
+           MAX(lefts[modelist[x]], lefts[modelist[y]]))) {
         ratio = (float) modelist[y] / (float) modelist[x];
         if (1.2 < ratio && ratio < 1.8) {
           /* Two modes found */
@@ -1679,8 +1685,9 @@ void pick_x_height(TO_ROW * row,                    //row to do
             found_one_bigger = FALSE;
             for (z = 0; z < MODENUM; z++) {
               if (modelist[z] == best_x_height + 1 &&
-                  MIN(rights[modelist[x]], rights[modelist[y]]) >
-                  MAX(lefts[modelist[x]], lefts[modelist[y]])) {
+                  (!textord_ocropus_mode ||
+                    MIN(rights[modelist[x]], rights[modelist[y]]) >
+                    MAX(lefts[modelist[x]], lefts[modelist[y]]))) {
                 ratio = (float) modelist[y] / (float) modelist[z];
                 if ((1.2 < ratio && ratio < 1.8) &&
                                /* Should be half of best */
@@ -1705,8 +1712,9 @@ void pick_x_height(TO_ROW * row,                    //row to do
             found_one_bigger = FALSE;
             for (z = 0; z < MODENUM; z++) {
               if (modelist[z] > best_asc &&
-                  MIN(rights[modelist[x]], rights[modelist[y]]) >
-                  MAX(lefts[modelist[x]], lefts[modelist[y]])) {
+                  (!textord_ocropus_mode ||
+                    MIN(rights[modelist[x]], rights[modelist[y]]) >
+                    MAX(lefts[modelist[x]], lefts[modelist[y]]))) {
                 ratio = (float) modelist[z] / (float) best_x_height;
                 if ((1.2 < ratio && ratio < 1.8) &&
                                /* Should be half of best */
