@@ -20,15 +20,21 @@
 // SVUtil contains the SVSync and SVNetwork classes, which are used for
 // thread/process creation & synchronization and network connection.
 
+#ifndef GRAPHICS_DISABLED
+
 #include "svutil.h"
 
 #ifdef WIN32
 #include <windows.h>
 #include <winsock.h>
 #else
+#include <arpa/inet.h>
+#include <netinet/in.h>
 #include <pthread.h>
 #include <semaphore.h>
 #include <signal.h>
+#include <stdlib.h>
+#include <string.h>
 #include <netdb.h>
 #include <sys/socket.h>
 #ifdef __linux__
@@ -37,7 +43,6 @@
 #endif
 
 #include <iostream>
-#include <string>
 
 const int kBufferSize = 65536;
 const int kMaxMsgSize = 4096;
@@ -59,8 +64,13 @@ void SVSync::StartProcess(const char* executable, const char* args) {
   proc.append(" ");
   proc.append(args);
   std::cout << "Starting " << proc << std::endl;
-  CreateProcess(NULL, const_cast<char*>(proc.c_str()), NULL,
-                NULL, FALSE, 0, NULL, NULL, NULL, NULL);
+  STARTUPINFO start_info;
+  PROCESS_INFORMATION proc_info;
+  GetStartupInfo(&start_info);
+  if (!CreateProcess(NULL, const_cast<char*>(proc.c_str()), NULL, NULL, FALSE,
+                CREATE_NO_WINDOW | DETACHED_PROCESS, NULL, NULL,
+                &start_info, &proc_info))
+    return;
 #else
   int pid = fork();
   if (pid != 0) {   // The father process returns
@@ -260,8 +270,9 @@ SVNetwork::SVNetwork(const char* hostname, int port) {
 #elif defined(__linux__)
   struct hostent hp;
   int herr;
-  char buffer[kBufferSize];
+  char *buffer = new char[kBufferSize];
   gethostbyname_r(hostname, &hp, buffer, kBufferSize, &name, &herr);
+  delete[] buffer;
 #else
   name = gethostbyname(hostname);
 #endif
@@ -288,29 +299,28 @@ SVNetwork::SVNetwork(const char* hostname, int port) {
       scrollview_path = ".";
 #endif
     }
-    // The following ugly pair of ifdefs are to enable the output of the
-    // java runtime to be sent down a black hole to ignore all the
+    // The following ugly ifdef is to enable the output of the java runtime
+    // to be sent down a black hole on non-windows to ignore all the
     // exceptions in piccolo. Ideally piccolo would be debugged to make
     // this unnecessary.
+    // Also the path has to be separated by ; on windows and : otherwise.
 #ifdef WIN32
-    const char* prog = "java";
-    const char* cmd_template =
+    const char* prog = "java -Xms512m -Xmx1024m";
+    const char* cmd_template = "-Djava.library.path=%s -cp %s/ScrollView.jar;"
+        "%s/piccolo-1.2.jar;%s/piccolox-1.2.jar"
+        " com.google.scrollview.ScrollView";
 #else
     const char* prog = "sh";
     const char* cmd_template = "-c \"trap 'kill %1' 0 1 2 ; java "
-#endif
-        "-Djava.library.path=%s -cp %s/luajava-1.1.jar:%s/ScrollView.jar:"
+        "-Xms1024m -Xmx2048m -Djava.library.path=%s -cp %s/ScrollView.jar:"
         "%s/piccolo-1.2.jar:%s/piccolox-1.2.jar"
         " com.google.scrollview.ScrollView"
-#ifdef WIN32
-        ;
-#else
-    " >/dev/null 2>&1 & wait\"";
+        " >/dev/null 2>&1 & wait\"";
 #endif
-    int cmdlen = strlen(cmd_template) + 5*strlen(scrollview_path) + 1;
+    int cmdlen = strlen(cmd_template) + 4*strlen(scrollview_path) + 1;
     char* cmd = new char[cmdlen];
     snprintf(cmd, cmdlen, cmd_template, scrollview_path, scrollview_path,
-             scrollview_path, scrollview_path, scrollview_path);
+             scrollview_path, scrollview_path);
 
     SVSync::StartProcess(prog, cmd);
     delete [] cmd;
@@ -333,3 +343,5 @@ SVNetwork::~SVNetwork() {
   delete[] msg_buffer_in_;
   delete mutex_send_;
 }
+
+#endif  // GRAPHICS_DISABLED
