@@ -90,6 +90,7 @@ void program_editup(const char *configfile) {
   /* Initialize subsystems */
   program_init();
   mfeature_init();
+  init_permute();
   setup_cp_maps();
 }
 
@@ -105,7 +106,6 @@ void program_editup2(const char *textbase) {
   init_metrics();
   pass2_ok_split = ok_split;
   pass2_seg_states = num_seg_states;
-  reset_width_tally();
 }
 
 
@@ -158,7 +158,7 @@ int end_recog() {
  * This function holds any nessessary post processing for the Wise Owl
  * program.
  **********************************************************************/
-void program_editdown(INT32 elasped_time) {
+void program_editdown(inT32 elasped_time) {
   dj_cleanup();
   if (display_text)
     cprintf ("\n");
@@ -189,7 +189,6 @@ void program_editdown(INT32 elasped_time) {
   }
   end_metrics();
   end_permute();
-  end_permdawg();
   free_variables();
 }
 
